from django.db import migrations


def populate_mac_addresses(apps, schema_editor):
    ContentType = apps.get_model('contenttypes', 'ContentType')
    VMInterface = apps.get_model('virtualization', 'VMInterface')
    MACAddress = apps.get_model('dcim', 'MACAddress')
    vminterface_ct = ContentType.objects.get_for_model(VMInterface)

    mac_addresses = [
        MACAddress(
            mac_address=vminterface._mac_address,
            assigned_object_type=vminterface_ct,
            assigned_object_id=vminterface.pk
        )
        for vminterface in VMInterface.objects.filter(_mac_address__isnull=False)
    ]
    MACAddress.objects.bulk_create(mac_addresses, batch_size=100)


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0199_macaddress'),
        ('virtualization', '0046_natural_ordering'),
    ]

    operations = [
        # Rename mac_address field to avoid conflict with property
        migrations.RenameField(
            model_name='vminterface',
            old_name='mac_address',
            new_name='_mac_address',
        ),
        migrations.RunPython(
            code=populate_mac_addresses,
            reverse_code=migrations.RunPython.noop
        ),
        migrations.RemoveField(
            model_name='vminterface',
            name='_mac_address',
        ),
    ]
